@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-from rplidar import RPLidar
+from rplidar import *
 import argparse
 import stretch_body.hello_utils as hu
 hu.print_stretch_re_use()
@@ -13,7 +13,11 @@ parser.add_argument("--reset", help="Reset device",action="store_true")
 parser.add_argument("--range", help="Print range reading",action="store_true")
 args=parser.parse_args()
 
-lidar = RPLidar('/dev/hello-lrf')
+try:
+    lidar = RPLidar('/dev/hello-lrf')
+except RPLidarException:
+    print ('RPLidar not present')
+    exit()
 prev_motor_running=lidar.motor_running
 
 if args.info:
